#!/bin/bash
# AWXcurrent v1, for Asterisk and FreePBX
#
# Gets your current weather conditions from WTTR.IN, and checks the BoM
# for any local Warnings (Sorry, Warnings are Australian only). It tries to
# detect a service error on first run for temp and bail if there's a problem

# You must set your areas Warning page ID Number below, you can find your ID
# at the bottom of most areas warning page on the BoM's web site.
#
# No suitable TTS service found that takes automated script submissions and
# returns a file, so for moment we stick with espeak, until we find better
# with non robotic sounding voices, Cepstral is good but non-free.
#
# Warnings can be anytime day or night, so we check for them every time we
# are getting current local conditions.
#
# This is a suitable cron entry for updating:
#
#    */20 * * * * /usr/local/sbin/AWXcurrent.sh > /dev/null 2>&1
#
# For security and integrity purposes we set the full path to each binary.
# For Asterisk and FreePBX configuration, see our blog post:
# https://blog.ausics.net/archives/159-Add-Current-Weather-In-FreePBX.html
#
# Copyright © Noel Butler <noelb@ausics.net> 2024  All Rights Reserved.
############################################################################
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License v3 as published by the
# Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
# more details. The original copyright notice must always remain unaltered.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>
#
############################################################################
#
# Set your local BoM locality for current conditions

LOCAL='Brisbane'

# Set your local BoM Warning IDQ (include .txt)

IDQTS='IDQ21035.txt'      # IDQ21035 SEQ Area TS Warning

# If something doesn't work, check paths to the binaries for your OS.
############################################################################

# Get Current Conditions from wttr.in
# This sets local files for FreePBX to poll, instead of trying remote polls for every call

/usr/bin/curl -s --connect-timeout 10 -o /var/tmp/WTEMP.tmp "https://wttr.in/$LOCAL?m&format='%t'"

if /bin/grep -q "Unknown" /var/tmp/WTEMP.tmp ; then
	/usr/bin/logger -t AWXcurrent "ERROR, Remote SVC Unavailable"
	exit
  else
	/usr/bin/test -s /var/tmp/WTEMP.tmp && /bin/mv /var/tmp/WTEMP.tmp /var/tmp/WTEMP
fi

/usr/bin/curl -s --connect-timeout 10 -o /var/tmp/WFTEMP.tmp "https://wttr.in/$LOCAL?m&format='%f'"
/usr/bin/test -s /var/tmp/WFTEMP.tmp && /bin/mv /var/tmp/WFTEMP.tmp /var/tmp/WFTEMP

/usr/bin/curl -s --connect-timeout 10 -o /var/tmp/WHUMID.tmp "https://wttr.in/$LOCAL?m&format='%h'"
/usr/bin/test -s /var/tmp/WHUMID.tmp && /bin/mv /var/tmp/WHUMID.tmp /var/tmp/WHUMID

/usr/bin/curl -s --connect-timeout 10 -o /var/tmp/WBAROM.tmp "https://wttr.in/$LOCAL?m&format='%P'"
/usr/bin/test -s /var/tmp/WBAROM.tmp && /bin/mv /var/tmp/WBAROM.tmp /var/tmp/WBAROM

/usr/bin/curl -s --connect-timeout 10 -o /var/tmp/WWINDS.tmp "https://wttr.in/$LOCAL?m&format='%w'"
/usr/bin/test -s /var/tmp/WWINDS.tmp && /bin/mv /var/tmp/WWINDS.tmp /var/tmp/WWINDS




#-----------------------------------------------------------------------------------------------#



# Check and get any Warnings that exist



cd /var/tmp


if [ -f /var/tmp/$IDQTS ]; then
       /bin/rm /var/tmp/$IDQTS
fi

if [ -f /var/tmp/TS.wav ]; then
       /bin/rm /var/tmp/TS.wav
fi


/usr/bin/wget ftp://ftp.bom.gov.au/anon/gen/fwo/$IDQTS


# no IDQ file means warnings withdrawn, so clear em out
if [ ! -f /var/tmp/$IDQTS ]; then
  [ -e /var/lib/asterisk/sounds/WXTS.wav ] && /bin/rm /var/lib/asterisk/sounds/{WXTS.wav,WXTS.alaw,WXTS.ulaw}
  exit 0
fi


# lets make double sure we bail here if there is nothing to do
/usr/bin/test -s /var/tmp/$IDQTS || exit 0



# This is for phone systems, we dont need all header and footer stuff, so lets clean it all up

/usr/bin/perl -i -ne 'print if /TOP PRIORITY/ .. /Emergency services advise people to/' $IDQTS

/usr/bin/perl -i -ne 'print unless /Emergency services advise people to/' $IDQTS


/usr/bin/perl -i -pe 's/(BROADCAST)(.*)$/$1$2./' $IDQTS
/usr/bin/perl -i -pe "s/\(east of/\,being east of/;" $IDQTS
/usr/bin/perl -i -pe "s/\)/,/g;" $IDQTS
/usr/bin/perl -i -pe "s/km\/h/kilometers per hour/g;" $IDQTS
/usr/bin/perl -i -pe "s/For people in/\. For people in/;" $IDQTS



/usr/bin/espeak -f /var/tmp/$IDQTS -ven-us+f2 -s160 -w /var/tmp/TS.wav

# bail here if espeak failed
/usr/bin/test -s /var/tmp/TS.wav || exit 0


# convert to asterisk formats
/usr/bin/sox /var/lib/asterisk/sounds/en/custom/ts-alert.wav /var/tmp/TS.wav -r 8000 -c 1 -t al /var/tmp/WXTS.alaw
/usr/bin/sox /var/lib/asterisk/sounds/en/custom/ts-alert.wav /var/tmp/TS.wav -r 8000 -c 1 -t ul /var/tmp/WXTS.ulaw
/usr/bin/sox /var/lib/asterisk/sounds/en/custom/ts-alert.wav /var/tmp/TS.wav -r 8000 -c 1 /var/tmp/WXTS.wav


# put them in place
/bin/mv /var/tmp/WXTS.wav /var/lib/asterisk/sounds
/bin/mv /var/tmp/WXTS.*law /var/lib/asterisk/sounds


/usr/bin/logger -t AWXcurrent "BoM Weather Warning Actioned"

exit 0
